self.__precacheManifest = [
  {
    "revision": "74cdedb8050c1198d3c477e62d8bd849",
    "url": "./static/media/logo.74cdedb8.png"
  },
  {
    "revision": "8c97409f0ee389fe75da",
    "url": "./static/js/runtime~main.d653cc00.js"
  },
  {
    "revision": "5b8ca075abb85bd0ec2f",
    "url": "./static/js/main.f8612d7c.chunk.js"
  },
  {
    "revision": "12ea26df2b64301b9a24",
    "url": "./static/js/2.4aeaad65.chunk.js"
  },
  {
    "revision": "5b8ca075abb85bd0ec2f",
    "url": "./static/css/main.95ffe78b.chunk.css"
  },
  {
    "revision": "5a0caccfbb073573186d26d8e73ab5b3",
    "url": "./index.html"
  }
];