body{font-family:-apple-system,BlinkMacSystemFont,Segoe UI,Roboto,Oxygen,Ubuntu,Cantarell,Fira Sans,Droid Sans,Helvetica Neue,sans-serif;-webkit-font-smoothing:antialiased;-moz-osx-font-smoothing:grayscale}code{font-family:source-code-pro,Menlo,Monaco,Consolas,Courier New,monospace}html{font-family:arial}body,html{height:100%;width:100%}body{background-color:#000;color:#fff;padding:0;margin:0}#root{height:100%}a{color:#555}.flexnowrap{display:flex;flex-wrap:nowrap;align-items:baseline}#statusbar,#top{display:flex;align-items:baseline;justify-content:space-evenly;color:#555;flex-wrap:nowrap;white-space:nowrap}#bottom div,#statusbar div{margin:2px}#bottom{display:flex;justify-content:space-between;color:#555;padding:5px}#terminal,#terminal-entry{padding:10px;overflow:auto;height:80vh}#terminal-entry{background:#000;font-size:2rem}input{margin:10px;height:50px;width:300px}button,input{font-size:2rem}#terminal.connection-pending{box-shadow:0 0 5px 2px #9bbaff}#terminal.connected{box-shadow:0 0 5px 2px #a1b570}#terminal.disconnected{box-shadow:0 0 5px 2px #bf3333}td{padding:3px}.led{width:10px;height:10px;border-radius:50%;background-color:hsla(0,0%,100%,.25);box-shadow:0 -1px 6px 1px #000}.led-red{background-color:red;box-shadow:0 -1px 6px 1px #000,inset 0 -1px 8px #600,0 3px 11px red}.led-orange{background-color:#ff7000;box-shadow:0 -1px 6px 1px #000,inset 0 -1px 8px #630,0 3px 11px #ff7000}.led-yellow{background-color:#ff0;box-shadow:0 -1px 6px 1px #000,inset 0 -1px 8px #660,0 3px 11px #ff0}.led-green{background-color:#80ff00;box-shadow:0 -1px 6px 1px #000,inset 0 -1px 8px #460,0 3px 11px #80ff00}.led-blue{background-color:#06f;box-shadow:0 -1px 6px 1px #000,inset 0 -1px 8px #006,0 3px 11px #06f}
/*# sourceMappingURL=main.95ffe78b.chunk.css.map */